@@ -1,8 +1,10 @@
 import datetime
+import random
 import time
 import copy
 
 from dateutil.relativedelta import relativedelta, MO
+from googleapiclient.errors import HttpError
 
 from pyganalytics.MetaGoogleAnalytics import MetaGoogleAnalytics
 from pyganalytics.core.load.to_database import send_to_db, def_table_name
@@ -20,7 +22,12 @@ def _get_one_segment(googleanalytics, report, all_view_id, start, end, time_incr
     metric_filter = report_config.get("metric_filter")
     dimension_filter = report_config.get("dimension_filter")
     segment = report_config.get("segment")
-    output_storage_name = def_table_name(prefix_schema, report_name, time_increment)
+    output_storage_name = def_table_name(
+        prefix_schema=prefix_schema,
+        report_name=report_name,
+        time_increment=time_increment,
+        googleanalytics=googleanalytics
+    )
 
     result = {
         "rows": []
@@ -66,7 +73,12 @@ def _get_data_by_segment(googleanalytics, start, end, report, all_view_id, incre
         all_time_increment = [force_time_increment]
     all_result = []
     for time_increment in all_time_increment:
-        table_name = def_table_name(prefix_schema=prefix_schema, report_name=report.get("name"), time_increment=time_increment)
+        table_name = def_table_name(
+            prefix_schema=prefix_schema,
+            report_name=report.get("name"),
+            time_increment=time_increment,
+            googleanalytics=googleanalytics
+        )
         start, end = get_start_end(start=start, end=end, table_name=table_name, dbstream=googleanalytics.dbstream)
 
         if time_increment == 'year':
@@ -75,15 +87,21 @@ def _get_data_by_segment(googleanalytics, start, end, report, all_view_id, incre
         else:
             if time_increment == 'day':
                 segments = segment_ndays_date(start, end, increment)
-            elif time == "week":
+            elif time_increment == "week":
                 week_start = datetime.datetime.strptime(start, "%Y-%m-%d") + relativedelta(weekday=MO(-1))
                 segments = segment_week_date(week_start.strftime("%Y-%m-%d"), end, increment)
             else:
                 segments = segment_month_date(start[:7] + "-01", end)
             i = 0
             for segment in segments:
-                segment_data = _get_one_segment(googleanalytics, report, all_view_id, segment[0], segment[1],
-                                                time_increment, prefix_schema)
+                for n in range(0, 5):
+                    try:
+                        segment_data = _get_one_segment(googleanalytics, report, all_view_id, segment[0], segment[1],
+                                                        time_increment, prefix_schema)
+                        break
+                    except HttpError as error:
+                        if error.resp.reason in ["internalServerError", "backendError"]:
+                            time.sleep((2 ** n) + random.random())
                 if i == 0:  # Concatenate to send to spreadsheet
                     result = segment_data
                     i = i + 1
